#
# spec file for package sparse
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sparse
Version:        20161117
Release:        9.1
Summary:        A semantic parser of source files
License:        MIT
Group:          Development/Tools/Building
Url:            https://sparse.wiki.kernel.org/index.php/Main_Page
Source:         sparse-%{version}.tar.xz
Patch0:         parse-add-support-for-no_sanitize_-attributes.patch
BuildRequires:  gcc-c++
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
%if 0%{?suse_version} > 1320 || 0%{?is_opensuse}
BuildRequires:  llvm-devel
%endif

%description
Sparse is a semantic parser of source files: it's neither a compiler
(although it could be used as a front-end for one) nor is it a
preprocessor (although it contains as a part of it a preprocessing
phase).

It is meant to be a small - and simple - library.  Scanty and meager,
and partly because of that easy to use.  It has one mission in life:
create a semantic parse tree for some arbitrary user for further
analysis.  It's not a tokenizer, nor is it some generic context-free
parser.  In fact, context (semantics) is what it's all about - figuring
out not just what the grouping of tokens are, but what the _types_ are
that the grouping implies.

Sparse is primarily used in the development and debugging of the Linux
kernel.

%package devel
Summary:        Devel files for sparse
Group:          Development/Libraries/C and C++

%description devel
Development headers and libraries for sparse.

%package inspect
Summary:        Inspect binary from sparse
Group:          Development/Libraries/C and C++

%description inspect
test-inspect is a gtk frontend for sparse.

%package llvm
Summary:        LLVM backed sparse
Group:          Development/Libraries/C and C++

%description llvm
LLVM backend for sparse, including sparsec

%prep
%setup -q
%patch0 -p1

%build
make \
  %{?_smp_mflags} \
  PREFIX=%{_prefix} \
  LIBDIR=%{_libdir} \
  MANDIR=%{_mandir} \
  PKGCONFIGDIR=%{_datadir}/pkgconfig \
  CFLAGS="%{optflags}" \
  V=1

%install
make \
  %{?_smp_mflags} \
  DESTDIR=%{buildroot} \
  PREFIX=%{_prefix} \
  LIBDIR=%{_libdir} \
  MANDIR=%{_mandir} \
  PKGCONFIGDIR=%{_datadir}/pkgconfig \
  install

%files
%defattr(-,root,root)
%doc LICENSE README FAQ
%{_bindir}/cgcc
%{_bindir}/c2xml
%{_bindir}/sparse
%{_mandir}/man1/cgcc.1%{ext_man}
%{_mandir}/man1/sparse.1%{ext_man}

%if 0%{?suse_version} > 1320 || 0%{?is_opensuse}
%files llvm
%defattr(-,root,root)
%{_bindir}/sparsec
%{_bindir}/sparse-llvm
%endif

%files inspect
%defattr(-,root,root)
%{_bindir}/test-inspect

%files devel
%defattr(-,root,root)
%{_includedir}/sparse
%{_libdir}/libsparse.a
%{_datadir}/pkgconfig/sparse.pc

%changelog
* Fri Feb  3 2017 mpluskal@suse.com
- Update to version 20161117 (boo#1023536):
  * .gitignore: add cscope and Qt project files
  * Add default case to switches on enum variables
  * Fix size calculation of unsized bool array
  * Do not drop 'nocast' modifier when taking the address.
  * Fix warning compiling sparse-llvm
  * sparse: add 'alloc_align' to the ignored attributes
  * sparse: ignore __assume_aligned__ attribute
  * sparse: add no_sanitize_address as an ignored attribute
  * Handle SForced in storage_modifiers
  * sparse: update __builtin_object_size() prototype
- Change _service to disabled to preven accidentally running it
- Switch back to naming based on date only
* Thu Aug  4 2016 jslaby@suse.com
- Switch to the chrisl's repo
- Update to version 0.5+git.20160223:
  * Ignore pure attribute in assignement
  * Add tests for the builtin INF and nan() functions.
  * sparse/parse.c: ignore hotpatch attribute
  * sparse, llvm: compile: skip function prototypes to avoid SIGSEGV
  * validation/prototype: regression for skipping prototypes
  * ptrlist: reading deleted items in NEXT_PTR_LIST()
  * .gitignore: add cscope and Qt project files
  * Add default case to switches on enum variables
  * Fix size calculation of unsized bool array
  * Do not drop 'nocast' modifier when taking the address.
- add parse-add-support-for-no_sanitize_-attributes.patch
* Sun May  8 2016 mpluskal@suse.com
- Change versioning to include latest release - 0.5+git.20150208
- Enable sparse-llvm
- Update dependencies
- Small spec file cleanup with spec-cleaner
- Make building more verbose
* Fri Oct  9 2015 jslaby@suse.com
- update to 20150124
  * Teach sparse about the __COUNTER__ predefined macro
  * Make macro expanded string immutable
  * s390x: add the proper defines for data types
* Wed Jan 14 2015 jslaby@suse.com
- update to 20141211
  * Ptr list sorting should use memmove instead of memcpy
  * build: allow use of PKG_CONFIG to override pkg-config
  * compile-i386.c: don't ignore return value of write(2)
  * parse.c: remove duplicate 'may_alias' ignored_attributes
  * cgcc: avoid passing a sparse-only option to cc
  * test-suite: remove bashism to avoid test failures
  * teach next_designators() use array_element_offset()
  * cgcc: use $ccom to set $multiarch_dir if not specified
  * cgcc: use only the cc command to determine $gcc_base_dir
  * Add support for multiarch system header files
  * don't run sparse{c,i} tests when sparse-llvm is disabled
  * Makefile: suppress error message from shell
  * don't call isdigit/tolower with a char argument
  * sparse: add 'gnu_inline' to the ignored attributes
  * Add the __restrict__ keyword
  * sparse: treat function pointers as pointers to const data
  * rename -Werror to -Wsparse-error
  * sparse: Make -Werror turn warnigns into errors
  * Use LLVM_CONFIG instead of llvm-config in Makefile
  * sparse-llvm: Fix LLVM 3.5 linker errors
  * Fix initializers in anonymous structs and unions
  * Make same_symbol list share the same scope
  * Fix scoping of extern symbols in block scope
  * round up the array element size to byte align
  * sparse: make bits_to_bytes round up instead of down
  * Minor clean up for option handling
  * lib.c: skip --param parameters
  * parse: support c99 [static ...] in abstract array declarators
  * sparse{i,c}: use LLVM_CONFIG to find llc and lli
  * build: allow use of LLVM_CONFIG to override llvm-config config script
  * Fix error at anoymous unions
  * Add test case for the ioc type check
  * Add test case for anonymous union initializer
  * Add test case for extern array
  * Use any previous initializer to size a symbol
  * Add warning about duplicate initializers
  * Support GCC's transparent unions
  * evaluate: split out implementation of compatible_assignment_types
  * validation/sizeof-bool: fix broken test case
  * sparse: Allow override of sizeof(bool) warning
  * Define __CHAR_BIT__
* Thu May 15 2014 danny.al-gaaf@bisect.de
- change License to new MIT
- update to latest git version 20140128 (sparse verion 0.5.0)
  - Sparse 0.5.0
  - Fix make dist failure
  - sparse: add built-in atomic memory access identifiers
  - gitignore: add 'version.h'
  - Update the information in README about using the library.
  - sparse: Also check bit_offset when checking implicit casts
  - FAQ: Remove outdated sections about the license
  - sparse: Relicense under the MIT license
  - Revert "Fix mistaken comparison that becomes a no-op."
  - Revert "Update the information in README about using the
    library."
  - sparse: add __builtin_va_arg_pack() and
    __builtin_va_arg_pack_len()
  - Fix expression type for floating point negation ('!')
  - Fix result type of relational and logical operators
  - symbol.c: Set correct size of array from parenthesized
    string initializer
  - sparse, llvm: die if error
  - sparse, llvm: set more data attributes
  - sparse, llvm: fix struct name generation
  - sparse, llvm: cache symbol_type() result
  - sparse, llvm: fix array size
  - sparse, llvm: use LLVM_DEFAULT_TARGET_TRIPLE
  - sparse, llvm: Use LLVM_HOSTTRIPLE
  - sparse, llvm: set target specification
  - sparse, llvm: improve pointer arithmetic handling
  - sparse, llvm: add a struct access test case
  - sparse, llvm: base load/store address type on
    insn_symbol_type()
  - sparse, llvm: de-duplicate load/store address calculation code
  - sparse, llvm: Fix resulting type of store address calculations
  - sparse, llvm: simplify function generation
  - sparse, llvm: fix phi generation
  - char.c: Fix parsing of escapes
  - Trivial: Remove redundant Makefile variable
  - sparse, llvm: fix link errors
  - fix SIGFPE caused by signed division overflow
  - Novafora license grant using MIT license.
* Mon May 20 2013 jslaby@suse.com
- update to 20130425
  * many fixes
* Sat Mar  9 2013 jslaby@suse.com
- update to the latest snapshot (20130225)
  * they stopped releasing, we have to use snapshots
  * many fixes
  * remove these:
  - sparse-0.4.4-add_error_to_ignore.patch
  - sparse-0.4.4-add_leaf_to_ignore.patch
  - sparse-0.4.4-add_m64_support.patch
  - sparse-0.4.4-add_vector_size_to_ignore.patch
* Sat Oct 27 2012 asn@cryptomilk.org
- Add sparse-0.4.4-add_error_to_ignore.patch: Ignore __error__
- Add sparse-0.4.4-add_leaf_to_ignore.patch: Ignore __leaf__
- Add sparse-0.4.4-add_vector_size_to_ignore.patch: Ignore __vector_size__
- Add sparse-0.4.4-add_m64_support.patch: Fix m32/m64 support.
* Mon Feb  6 2012 cfarrell@suse.com
- license update: SUSE-OSL-1.1
  Spec file licenses are written in SPDX compatible format. Where there is
  no short name available at spdx.org/licenses use one of the SUSE-
  proprietary prefixes until the license is pushed upstream. In this case
  SUSE-OSL-1.1
* Thu Jan  5 2012 jslaby@suse.de
- update to 0.4.4
  * fixes in asm handling, binary constants and others
  * some other cleanups
* Mon Sep 19 2011 coolo@suse.com
- make the _service localonly
* Sat Apr 30 2011 jslaby@suse.de
- fix build with gcc 4.6
- package test-inspect and c2xml
- update to 0.4.3
  * Fixup and cleanup modifier_string() function.
  * inspect: add custom ast treeview model
  * inspect: add some example inspect for symbol and statement
  * inspect: add some expression inspection
  * inspect: Add test-inspect program
  * inspect: cast expression
  * parser: add Blackfin gcc info
  * skip may_alias and declare builtin_fabs
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Fri Jul 16 2010 jslaby@suse.de
- update to git commit 8832df8 (see git log for changes)
- some gcc 4.5 features added:
  * support for asm-gotos
  * support builtin_unreachable
* Fri May  7 2010 jslaby@suse.de
- update to git commit b4ef556 (see git log for changes)
- add a devel package containing
  * includes
  * static library (dynamic library is slow due to fPIC)
  * pkgconfig file
- update urls
- add "Git revision" line to the description
* Sun Dec 13 2009 jengelh@medozas.de
- enable parallel building
* Wed Sep 24 2008 jeffm@suse.com
- updated to 0.4.1.git1:
  * This snapshot corresponds to
    git commit 8f208e215a531d2b32aec0428fd5eaa24ae3100b.
  * lots of fixes - see
    http://git.kernel.org/?p=devel/sparse/sparse.git;a=shortlog
* Thu Jun 26 2008 tiwai@suse.de
- updated to version 0.4.1:
  * lots of fixes/improvements - see
    http://www.kernel.org/pub/software/devel/sparse/news.html
* Tue Nov 14 2006 agruen@suse.de
- Initial package.
